@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -58,7 +58,10 @@ class VizierServiceClientMeta(type):
     _transport_registry["grpc"] = VizierServiceGrpcTransport
     _transport_registry["grpc_asyncio"] = VizierServiceGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[VizierServiceTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[VizierServiceTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -167,10 +170,16 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         return self._transport
 
     @staticmethod
-    def custom_job_path(project: str, location: str, custom_job: str,) -> str:
+    def custom_job_path(
+        project: str,
+        location: str,
+        custom_job: str,
+    ) -> str:
         """Returns a fully-qualified custom_job string."""
         return "projects/{project}/locations/{location}/customJobs/{custom_job}".format(
-            project=project, location=location, custom_job=custom_job,
+            project=project,
+            location=location,
+            custom_job=custom_job,
         )
 
     @staticmethod
@@ -183,10 +192,16 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def study_path(project: str, location: str, study: str,) -> str:
+    def study_path(
+        project: str,
+        location: str,
+        study: str,
+    ) -> str:
         """Returns a fully-qualified study string."""
         return "projects/{project}/locations/{location}/studies/{study}".format(
-            project=project, location=location, study=study,
+            project=project,
+            location=location,
+            study=study,
         )
 
     @staticmethod
@@ -199,10 +214,18 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def trial_path(project: str, location: str, study: str, trial: str,) -> str:
+    def trial_path(
+        project: str,
+        location: str,
+        study: str,
+        trial: str,
+    ) -> str:
         """Returns a fully-qualified trial string."""
         return "projects/{project}/locations/{location}/studies/{study}/trials/{trial}".format(
-            project=project, location=location, study=study, trial=trial,
+            project=project,
+            location=location,
+            study=study,
+            trial=trial,
         )
 
     @staticmethod
@@ -215,7 +238,9 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -228,9 +253,13 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -239,9 +268,13 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -250,9 +283,13 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -261,10 +298,14 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -452,8 +493,7 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         after creation of the Study.
 
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1
 
@@ -544,7 +584,12 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -560,8 +605,7 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
     ) -> study.Study:
         r"""Gets a Study by name.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1
 
@@ -633,7 +677,12 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -651,8 +700,7 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         project.
 
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1
 
@@ -731,12 +779,20 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListStudiesPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -753,8 +809,7 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
     ) -> None:
         r"""Deletes a Study.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1
 
@@ -821,7 +876,10 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
 
         # Send the request.
         rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     def lookup_study(
@@ -837,8 +895,7 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         instead of the fully qualified resource name.
 
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1
 
@@ -912,7 +969,12 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -932,8 +994,7 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         [SuggestTrialsResponse][google.cloud.ml.v1.SuggestTrialsResponse].
 
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1
 
@@ -997,7 +1058,12 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1022,8 +1088,7 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
     ) -> study.Trial:
         r"""Adds a user provided Trial to a Study.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1
 
@@ -1108,7 +1173,12 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1124,8 +1194,7 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
     ) -> study.Trial:
         r"""Gets a Trial.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1
 
@@ -1202,7 +1271,12 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1218,8 +1292,7 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
     ) -> pagers.ListTrialsPager:
         r"""Lists the Trials associated with a Study.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1
 
@@ -1298,12 +1371,20 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListTrialsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -1322,8 +1403,7 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         before the Trial is complete.
 
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1
 
@@ -1382,7 +1462,12 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1397,8 +1482,7 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
     ) -> study.Trial:
         r"""Marks a Trial as complete.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1
 
@@ -1455,7 +1539,12 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1471,8 +1560,7 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
     ) -> None:
         r"""Deletes a Trial.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1
 
@@ -1538,7 +1626,10 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
 
         # Send the request.
         rpc(
-            request, retry=retry, timeout=timeout, metadata=metadata,
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
 
     def check_trial_early_stopping_state(
@@ -1555,8 +1646,7 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         [CheckTrialEarlyStoppingStateResponse][google.cloud.ml.v1.CheckTrialEarlyStoppingStateResponse].
 
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1
 
@@ -1622,7 +1712,12 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -1645,8 +1740,7 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
     ) -> study.Trial:
         r"""Stops a Trial.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1
 
@@ -1703,7 +1797,12 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -1723,8 +1822,7 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         https://en.wikipedia.org/wiki/Pareto_efficiency
 
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1
 
@@ -1798,7 +1896,12 @@ class VizierServiceClient(metaclass=VizierServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
